@@ -11,10 +11,12 @@ def get_target_color(img):
         for i in range(256):
             if i not in colorset:
                 return i
+        return 0
     if img.image.format.upper() == 'PNG':
         for color in nested_int_loop([256] * len(img.load()[0,0])):
             if color not in colorset:
                 return color
+        return [0] * len(img.load()[0,0])
 
 class ImageLayer:
     def __init__(self, image, pixelcoords=[], color=(0,0,0,255)):
@@ -82,8 +84,8 @@ class ImageLayer:
 class OptimalColors:
     def __init__(self, colors: tuple):
         for tup in colors:
-            if type(tup) not in [list, tuple]:
-                raise ValueError('Color must be tuple or list')
+            if type(tup) not in [list, tuple, int]:
+                raise ValueError('Color must be tuple or list or int')
         self.colors = colors
 
     def adjustpixelrgb(self, pixel, limit=1, shift=0):
@@ -105,14 +107,23 @@ class OptimalColors:
                 return mr,mg,mb,ma
         return pixel
     
+    def adjustpixelbw(self, pixel, limit=1, shift=0):
+        for bw in self.colors:
+            if bw - limit + shift < pixel < bw + limit + shift:
+                return bw
+    
     def optimize_image(self, image, tolerance=1, bwshift=0):
         px = image.load()
         for x in range(image.width):
             for y in range(image.height):
                 try:
-                    px[x,y] = self.adjustpixelrgb(px[x,y], tolerance, bwshift)
-                except ValueError:
-                    px[x,y] = self.adjustpixelrgba(px[x,y], tolerance, bwshift)
+                    px[x,y] = self.adjustpixelbw(px[x,y], tolerance, bwshift)
+                except TypeError:
+                    try:
+                        px[x,y] = self.adjustpixelrgb(px[x,y], tolerance, bwshift)
+                    except ValueError:
+                        px[x,y] = self.adjustpixelrgba(px[x,y], tolerance, bwshift)
+
 
 class LayeredImage:
     def __init__(self, image):
